API docs for “spamfighter.interfaces.IMessageDomain”

# Class s.i.IMessageDomain(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Список доменов атрибутов, которые должны быть у сообщения.

Такой объект хранится в домене.

Method | names | Получить список имен доменов атрибутов.
Method | __getitem__ | Получить домен атрибута по имени.

def names(): (source)
Получить список имен доменов атрибутов.

Returns | список имен (type: `list(str)` )

def __getitem__(key): (source)
Получить домен атрибута по имени.

Parameters | key | имя атрибута (type: `str` )
Returns | атрибут домена (type: `IAttributeDomain` )